## ----include=FALSE----------------------------------------------------------------------------------------------------
suppressPackageStartupMessages(library("lessR"))

## ---------------------------------------------------------------------------------------------------------------------
d <- Read("Employee")

## ---------------------------------------------------------------------------------------------------------------------
d[.(Gender=="M" & Post>90), .(Years:Salary, Post)]

## ---------------------------------------------------------------------------------------------------------------------
d[d$Gender=="M" & d$Post>90, c("Years", "Gender", "Dept", "Salary", "Post")]

## ---------------------------------------------------------------------------------------------------------------------
d[.(!(Gender=="M" & Post>90)), -.(Dept:Plan, Pre)]

## ---------------------------------------------------------------------------------------------------------------------
d[1:3, .(Years:Salary, Post)]
d[.(Gender=="M" & Post>90), 1:3]

## ---------------------------------------------------------------------------------------------------------------------
rows <- "Gender=='M' & Post>93"
cols <- "Gender:Salary, Post"

## ---------------------------------------------------------------------------------------------------------------------
d[.(rows), .(cols)]

## ---------------------------------------------------------------------------------------------------------------------
d[.(!rows), -.(cols)]

## ---------------------------------------------------------------------------------------------------------------------
d[1:5,]

## ---------------------------------------------------------------------------------------------------------------------
d[d$Dept=="ADMN", c('Gender', 'Dept', 'Salary')]

## ---------------------------------------------------------------------------------------------------------------------
d[.(Dept=="ADMN"), .(Gender:Salary)]

## ---------------------------------------------------------------------------------------------------------------------
d[.(random(5)), .(Years:Salary)]

## ---------------------------------------------------------------------------------------------------------------------
d[.(random(0.1)), .(Years:Salary)]

